omin-methods: Extract Image Attribute omin
Description
Methods that act on the omin field in the
NIfTI/ANALYZE header.
Usage
omin(object)# S4 method for anlz
omin(object)
omin(object) <- value
# S4 method for anlz
omin(object) <- value
Arguments
object
is an object of class nifti or anlz.
value
is the value to assign to the omin field.
Details
See documentation on the ANALYZE and/or NIfTI data standards for
more details.